package core.api.models.timemanager.tasks;

import core.api.models.timemanager.taskgroup.TaskgroupEntityInfo;
import core.entities.timemanager.Task;
import core.entities.timemanager.Taskgroup;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

public class TaskTaskgroupInfo {

    private long taskID;
    private String taskName;

    private int eta;

    private LocalDate startDate;

    private LocalDate deadline;

    private boolean overdue;

    private boolean finished;

    private int workTime;

    private List<TaskgroupEntityInfo> taskgroups;

    private boolean finishable;

    public TaskTaskgroupInfo(Task task) {
        this.taskID = task.getTaskID();
        this.taskName = task.getTaskName();
        this.eta = task.getEta();
        this.startDate = task.getStartDate();
        this.deadline = task.getDeadline();
        if(task.getDeadline() != null) {
            this.overdue = LocalDate.now().isAfter(task.getDeadline());
        }
        this.finished = task.isFinished();
        this.workTime = task.getWorkTime();

        List<Taskgroup> taskgroupList = Taskgroup.getAncestorList(task.getTaskgroup());
        taskgroupList.add(task.getTaskgroup());
        this.taskgroups = taskgroupList.stream().map(TaskgroupEntityInfo::new).toList();
        this.finishable = task.isFinishable();
    }

    public long getTaskID() {
        return taskID;
    }

    public void setTaskID(long taskID) {
        this.taskID = taskID;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public int getEta() {
        return eta;
    }

    public void setEta(int eta) {
        this.eta = eta;
    }

    public LocalDate getStartDate() {
        return startDate;
    }

    public void setStartDate(LocalDate startDate) {
        this.startDate = startDate;
    }

    public LocalDate getDeadline() {
        return deadline;
    }

    public void setDeadline(LocalDate deadline) {
        this.deadline = deadline;
    }

    public boolean isOverdue() {
        return overdue;
    }

    public void setOverdue(boolean overdue) {
        this.overdue = overdue;
    }

    public boolean isFinished() {
        return finished;
    }

    public void setFinished(boolean finished) {
        this.finished = finished;
    }

    public int getWorkTime() {
        return workTime;
    }

    public void setWorkTime(int workTime) {
        this.workTime = workTime;
    }

    public List<TaskgroupEntityInfo> getTaskgroups() {
        return taskgroups;
    }

    public void setTaskgroups(List<TaskgroupEntityInfo> taskgroups) {
        this.taskgroups = taskgroups;
    }

    public boolean isFinishable() {
        return finishable;
    }

    public void setFinishable(boolean finishable) {
        this.finishable = finishable;
    }
}
