package core.services.ntfy;


import core.NotTest;
import org.quartz.*;
import org.quartz.impl.StdSchedulerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;

@Service
@NotTest
public class TaskSchedulingService {

    @Value("${ntfy.host}")
    private String ntfy_host;

    @Value("${ntfy.topic}")
    private String ntfy_topic;

    @Value("${frontend.domain}")
    private String frontend_domain;

    public void scheduleStartingTask(String taskName) throws SchedulerException {
        Scheduler scheduler = StdSchedulerFactory.getDefaultScheduler();
        scheduler.start();

        JobDetail job = JobBuilder.newJob(NtfyTaskStartNotification.class).build();
        job.getJobDataMap().put("task", taskName);
        job.getJobDataMap().put("ntfy_host", ntfy_host);
        job.getJobDataMap().put("ntfy_topic", ntfy_topic);
        job.getJobDataMap().put("frontend_domain", frontend_domain);

        Trigger immediatly = TriggerBuilder.newTrigger().startNow().build();

        scheduler.scheduleJob(job, immediatly);
    }

   public static void scheduleTask() throws SchedulerException {
       Scheduler scheduler = StdSchedulerFactory.getDefaultScheduler();
       scheduler.start();

       JobDetail job = JobBuilder.newJob(NtfyTask.class).build();

       job.getJobDataMap().put("data", "A simple Job 1 Message");

       LocalDateTime executionTime = LocalDateTime.of(2024, 3, 14, 9, 18); // Example: March 15, 2024, 10:00 AM

       Trigger trigger = TriggerBuilder.newTrigger()
               .withIdentity("trigger1", "Group 1")
               .startAt(calculateDelayInMillis(executionTime)).build();
       Trigger trigger2 = TriggerBuilder.newTrigger()
               .withIdentity("trigger2", "Group 1")
               .startAt(calculateDelayInMillis(executionTime.plusMinutes(1))).build();

       Trigger immediatly = TriggerBuilder.newTrigger().withIdentity("Immediately", "Group 1").startNow().build();

       scheduler.scheduleJob(job, immediatly);
   }

    private static Date calculateDelayInMillis(LocalDateTime executionTime) {
        return  Date.from(executionTime.atZone(ZoneId.systemDefault()).toInstant());
    }
}
